%if 0%{?with_debug}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%global provider        github
%global provider_tld    com
%global project         coreos
%global repo            flannel
%global project_dir     %{provider}.%{provider_tld}/%{project}
%global src_project_dir src/%{project_dir}
%global src_flannel_dir %{src_project_dir}/%{repo}
%global provider_prefix %{project_dir}/%{repo}
%global import_path     %{provider_prefix}


%global golang_version      1.12.10
%global golang_version_hash aaa84147433aed24e70b31da369bb6ca2859464a45de47c2a5023d8573412f6b


Name:           flannel
Version:        0.10.0
Release:        2.1.9%{?dist}
Summary:        Etcd address management agent for overlay networks
License:        ASL 2.0
Group:          System/Management
URL:            https://%{provider_prefix}
Vendor:         Oracle America
Source0:        %{name}-%{version}.tar.bz2


BuildRequires:      golang >= 1.12.10
BuildRequires:      pkgconfig(systemd)

Requires:     net-tools
Requires:     iproute
Requires:     iptables
Requires:     ca-certificates 

%description
Flannel is an etcd driven address management agent. Most commonly it is used to
manage the ip addresses of overlay networks between systems running containers
that need to communicate with one another.

%prep
%setup -q -n %{repo}-%{version}

find . -name "*.go" \
       -print |\
              xargs sed -i 's/github.com\/coreos\/flannel\/Godeps\/_workspace\/src\///g'


%build
mkdir -p %{src_project_dir}
ln -s ../../../ %{src_flannel_dir}

# GOLANG use upstream
mkdir -p $(pwd)/.gobin
GO_TGT=go%{golang_version}.linux-amd64.tar.gz
GO_SUM=%{golang_version_hash}
curl -fSL https://golang.org/dl/${GO_TGT} > ${GO_TGT}
CHKSUM=$(sha256sum ${GO_TGT} | cut -d' ' -f1)

if [[ "${CHKSUM}" != "${GO_SUM}" ]]; then
    echo "golang upstream binary checksum doesn't match"
    exit 1
fi

tar xzC $(pwd)/.gobin < ${GO_TGT}
export GOROOT=$(pwd)/.gobin/go
export GOBIN=$(pwd)/.gobin/go/bin
export PATH=$GOBIN:$PATH

export GOPATH=$(pwd):$(pwd)/Godeps/_workspace:%{gopath}

%define gobuild(o:) go build -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n')" -a -v -x %{?**};
%gobuild -o bin/flanneld %{import_path}

%install
mkdir -p %{buildroot}/opt/bin
install -D -p -m 755 bin/flanneld %{buildroot}/opt/bin/flanneld
install -D -p -m 755 dist/mk-docker-opts.sh %{buildroot}/opt/bin/mk-docker-opts.sh
mkdir -p %{buildroot}/run
install -d -m 0755 %{buildroot}/run/%{name}/


%check

%post
/usr/bin/update-ca-trust

%preun

%postun


%files
%license LICENSE THIRD_PARTY_LICENSES.txt
%doc CONTRIBUTING.md MAINTAINERS README.md DCO NOTICE
/opt/bin/flanneld
/opt/bin/mk-docker-opts.sh
%dir /run/%{name}/

%changelog
* Fri Oct 18 2019 Murali Annamneni <murali.annamneni@oracle.com> 0.10.0-2.1.9
- Added -1 in container image tag to differentiate with v0.10.0

* Thu Oct 17 2019 Murali Annamneni <murali.annamneni@oracle.com> 0.10.0-2.1.8
- Added THIRD_PARTY_LICENSES.txt

* Wed Oct 16 2019 Murali Annamneni <murali.annamneni@oracle.com> 0.10.0-2.1.7
- CVE-2019-16276 fix (bumpup golang to 1.12.10)

* Mon May 13 2019 Tom Cocozzello <tom.cocozzello@oracle.com> - 0.10.0-2.1.6
- Add container image building into pipeline

* Tue Apr 16 2019 Mark Duggan <mark.duggan@oracle.com> - 0.10.0-2.1.5
- Removing docker image. Building in pipeline

* Mon Feb 04 2019 Tom Cocozzello <tom.cocozzello@oracle.com> - 0.10.0-2.1.4
- CVE-2019-6486

* Wed Nov 21 2018 Muminul Islam <muminul.islam@oracle.com> - 0.10.0-2.0.4
- Fix ENTRYPOINT double quote issue

* Fri Nov 9 2018 Muminul Islam <muminul.islam@oracle.com> - 0.10.0-2.0.3
- Change the version for production

* Thu Nov 8 2018 Muminul Islam <muminul.islam@oracle.com> - 0.10.0-2.0.2
- Remove amd64 postfix and merge upstream pull #1045

* Fri Nov 2 2018 Muminul Islam <muminul.islam@oracle.com> - 0.10.0-2.0.1
- Update to v0.10.0, add oracle specific changes
